@@ -830,6 +830,7 @@ supported_keywords = dict(
     dependency_links=(str, list),
     tests_require=(str, list),
     autodiscover=bool,  # setuputils keyword
+    sorted_output=bool,  # setuputils keyword
     egg_base=str,
 )
 
@@ -1062,26 +1063,28 @@ def write_section_header(lines, section):
     lines.append("[{}]\n".format(section))
 
 
-def write_item_lines(lines, item, value):
+def write_item_lines(lines, item, value, sorted_output=True):
     if isinstance(value, list):
         lines.append("{} =\n".format(item))
+        if sorted_output:
+            value.sort()
         for v in value:
             lines.append("    {}\n".format(v))
     else:
         lines.append("{} = {}\n".format(item, value))
 
 
-def write_section_items(lines, item_vars):
+def write_section_items(lines, item_vars, sorted_output=True):
     for item, value in item_vars.items():
         if value and not isinstance(value, dict):
-            write_item_lines(lines, item, value)
+            write_item_lines(lines, item, value, sorted_output=sorted_output)
 
 
 def write_section_close(lines):
     lines.append("\n")
 
 
-def write_out_file(cfg_vars):
+def write_out_file(cfg_vars, sorted_output=True):
     lines = []
     for section, items in setup_cfg_sections:
         if items:
@@ -1090,14 +1093,16 @@ def write_out_file(cfg_vars):
             key = section.split(".", 1)[-1]
             item_vars = cfg_vars.get(key)
         if item_vars and isinstance(item_vars, dict):
+            if sorted_output and not items:
+                item_vars = {k: item_vars[k] for k in sorted(item_vars)}
             write_section_header(lines, section)
-            write_section_items(lines, item_vars)
+            write_section_items(lines, item_vars, sorted_output=sorted_output)
             write_section_close(lines)
     with open("setup.cfg", "w") as f:
         f.writelines(lines)
 
 
-def write_setup_cfg(autodiscover=True):
+def write_setup_cfg(autodiscover=True, sorted_output=True):
     if os.path.isfile('setup.py'):
         varmap = read_setup_py()
         #raise RuntimeError("Cannot have setup.py file in setup.cfg mode.")
@@ -1105,11 +1110,12 @@ def write_setup_cfg(autodiscover=True):
         varmap = {}
     varmap.update(read_in_files())
     autodiscover = varmap.get('autodiscover', autodiscover)
+    sorted_output = varmap.get('sorted_output', sorted_output)
     cfg_vars = setup_vars(varmap, autodiscover=autodiscover, force_manifest_in=None)
     forbidden_keys = [k for k in cfg_vars if k in no_setup_cfg_keys]
     if forbidden_keys:
         raise RuntimeError("Keys {} are not supported in setup.cfg.".format(", ".join(forbidden_keys)))
-    write_out_file(cfg_vars)
+    write_out_file(cfg_vars, sorted_output=sorted_output)
 
 
 if __name__ == '__main__':
